@@ -17,10 +17,6 @@
 
 #include <istream>
 
-#ifdef WIN32 //TODO: Why do we do this? murrayc.
-#define vsnprintf _vsnprintf
-#endif
-
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 extern "C" {
   struct _xmlParserCtxt;
@@ -82,6 +78,8 @@ public:
    */
   virtual void parse_stream(std::istream& in) = 0;
 
+  //TODO: Add stop_parser()/stop_parsing(), wrapping XmlStopParser()?
+
 protected:
   virtual void initialize_context();
   virtual void release_underlying();
